@@ -7,6 +7,7 @@ from numpy import dtype, float16, float32, float64, uint16, uint32, uint64, int1
 
 from kamzik3 import units
 from kamzik3.constants import *
+from kamzik3.constants import SAVE_CHANGE
 from kamzik3.snippets.snippetDataAccess import is_equal
 
 
@@ -48,7 +49,7 @@ class Attribute(dict):
 
     def __init__(self, attribute_id=None, default_value=None, min_value=None, max_value=None, unit=None,
                  set_function=None, default_type=u"str", decimals=0, readonly=False, description=None,
-                 set_value_when_set_function=True, tolerance=(0, 0), factor=1, offset=0, **kwargs):
+                 set_value_when_set_function=True, tolerance=(0, 0), factor=1, offset=0, save_change=False, **kwargs):
         dict.__init__(self)
         self._callbacks = {}
         self.attribute_id = attribute_id
@@ -94,6 +95,7 @@ class Attribute(dict):
         self[VALUE] = default_value
         self[SETPOINT] = None
         self[PREVIOUS] = None
+        self[SAVE_CHANGE] = save_change
         self.update(kwargs)
 
     def _update_set_time(self):
