@@ -53,6 +53,7 @@ class Device(Subject, YamlSerializable):
     command_retry_count = 0
     push_commands_max = inf
     push_buffer_size = 2 ** 16
+    command_encoding = "utf8"
 
     def __init__(self, device_id=None, config=None):
         self.connecting_time = 0
@@ -445,7 +446,7 @@ class Device(Subject, YamlSerializable):
         if propagate_change:
             value = attribute_object[attribute_list[-1]]
             if not is_equal(current_value, value) and kamzik3.session.publisher is not None:
-                if attribute_object[SAVE_CHANGE]:
+                if self.session and attribute_object[SAVE_CHANGE]:
                     self.session.update_config(self.device_id, attribute_list, value)
                 header = "{}.{}".format(attribute_object.attribute_id, attribute_list[-1])
                 kamzik3.session.publisher.push_message(header, value, min_timeout=attribute_object.min_stream_timeout)
@@ -595,7 +596,10 @@ class Device(Subject, YamlSerializable):
                 u"Trying to pop from empty command buffer. Content of readout buffer is: {}".format(readout_buffer))
             return RESPONSE_ERROR, "", None, False
 
-        return attribute, "".join(readout_buffer), callback, token
+        if self.command_encoding is None:
+            return attribute, readout_buffer, callback, token
+        else:
+            return attribute, "".join(readout_buffer), callback, token
 
     def disconnect(self):
         """
@@ -771,15 +775,15 @@ class Device(Subject, YamlSerializable):
         try:
             mark = time.time()
             if self.connected:
-                command_string = u""
+                command_data = b"" if self.command_encoding is None else ""
                 commands_to_push_counter = 0
                 while commands:
                     command = commands.pop(0)
                     commands_to_push_counter += 1
-                    command_string += command[0]
-                    if len(command_string) > self.push_buffer_size:
+                    command_data += command[0]
+                    if len(command_data) > self.push_buffer_size:
                         commands.insert(0, command)
-                        command_string = command_string[:-len(command[0])]
+                        command_data = command_data[:-len(command[0])]
                         break
                     if command[3]:  # If command is returning
                         self.commands_buffer.append((command, mark))
@@ -787,7 +791,7 @@ class Device(Subject, YamlSerializable):
                         self.response_timestamp = mark
                     if commands_to_push_counter >= self.push_commands_max:
                         break
-                self.push(command_string.encode())
+                self.push(command_data if self.command_encoding is None else command_data.encode(self.command_encoding))
             else:
                 self.handle_response_error(u"Device is not connected")
         except IndexError:
