@@ -111,12 +111,6 @@ class DeviceClient(Device):
             for attribute_id in self.attributes_sharing_map:
                 self._subscribe(attribute_id)
 
-    def reconnect_allowed(self):
-        if self.connected:
-            return False
-        else:
-            return self.allow_reconnect
-
     def _init_subscriber_thread(self):
         """
         We are connected to the main server.
@@ -252,7 +246,8 @@ class DeviceClient(Device):
                     attribute_path = attribute_parts[2:]
 
                     if attribute_id in self.attributes_sharing_map:
-                        self._set(self.attributes_sharing_map[attribute_id] + [attribute_parts[-1]], data)
+                        for shared_attribute in self.attributes_sharing_map[attribute_id]:
+                            self._set(shared_attribute + [attribute_parts[-1]], data)
                     if token.startswith(self.subscribe_starts_with_list):
                         self._set(attribute_path, data)
             else:
@@ -503,7 +498,7 @@ class DeviceClient(Device):
         self.logger.info(u"Device configuration took {} sec.".format(time.time() - start_at))
 
     def handle_response_error(self, message=None):
-        self.logger.error(message)
+        self.logger.warning(message)
         self.response_error = True
         self.close()
 
