@@ -28,7 +28,7 @@ def get_attribute_unit_range(attribute):
     elif base_unit in ("bar", "Pa", "atm"):
         return ["mbar", "bar", "Pa", "kPa", "atm"]
     elif base_unit == "revolutions_per_minute":
-        return ["rpm"]
+        return ["rpm", "rps"]
     else:
         sorted_prefixes = (
             'y', 'z', 'a', 'f', 'p', 'n', 'u', 'm', 'c', 'd', "", 'da', 'h', 'k', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y'
